Inflection
==========

|build status|_

.. |build status| image:: https://secure.travis-ci.org/jpvanhal/inflection.png?branch=master
   :alt: Build Status
.. _build status: http://travis-ci.org/jpvanhal/inflection

Inflection is a string transformation library.  It singularizes and pluralizes
English words, and transforms strings from CamelCase to underscored string.
Inflection is a port of `Ruby on Rails`_' `inflector`_ to Python.

.. _Ruby on Rails: http://rubyonrails.org
.. _inflector: http://api.rubyonrails.org/classes/ActiveSupport/Inflector.html

Resources
---------

- `Documentation <http://inflection.readthedocs.org/>`_
- `Issue Tracker <http://github.com/jpvanhal/inflection/issues>`_
- `Code <http://github.com/jpvanhal/inflection>`_
- `Development Version
  <http://github.com/jpvanhal/inflection/zipball/master#egg=Inflection-dev>`_
